﻿function Set-ELHCConfig
{
    #Requires -RunasAdministrator
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]
    Param (
        [Parameter (Mandatory=$False)]
        [ValidateScript({ Test-Path -Path $_ -PathType File })]
        [string]$BaseConfigPath = (Split-Path $PSScriptRoot -Parent) + "\Base.config"
    )

    [xml]$BaseConfig = Get-Content $BaseConfigPath

    Write-Output "`nTime to generate a configuration for ELHC.  This command just does the basics -- to fine tune, modify ELHC.config in your favorite text editor.`n"
    
    [string]$DepartmentName = Read-Host -Prompt "What is the department name? (e.g., McKinney PD)"
    $BaseConfig.root.DepartmentName = $DepartmentName
    $BaseConfig.root.DepartmentID = [guid]::NewGuid().tostring()
    
    $ConnectionStringInstance = Read-Host -Prompt "Where is the SQL instance?  (if this is an all-in-one, press enter)"
    if ($ConnectionStringInstance -eq $null -or $ConnectionStringInstance -eq "") {
        $ConnectionStringInstance = '(local)'
    }
    
    $BaseConfig.root.ConnectionString = "data source=$ConnectionStringInstance;initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    $BaseConfig.root.ELHCVersion = (Get-InstalledModule ELHealthcheck).Version.ToString()
    
    $OldErrorPref = $ErrorActionPreference
    #$ErrorActionPreference = 'silentlycontinue'
            
    $Substation = . {
        $DriveLetters = @('C','D','E')
        foreach ($Letter in $DriveLetters) {
            $Path = "$($Letter):\Program Files\WatchGuard Video\Hosted Services\Services.Host.WinService.exe.config"
            if (test-path $Path) {
                [xml]$HostedConfig = Get-Content -Path $path
                break
            }
            else {
                write-warning "Didn't find anything at $Path..."
            }
        }


        $SSID = ($HostedConfig.configuration.appSettings.add | where {$_.key -eq 'SubstationIdentity'}).value
        if ($SSID -eq $null -or $HostedConfig -eq $null) {
            Write-Warning "Could not find SubstationID in the hosted config.  You'll have to specify this manually."
        }
        else {
            Write-Output "Substation ID : $SSID"
            $BaseConfig.root.SubstationID = $SSID
        }
    }

    $ErrorActionPreference = $OldErrorPref

    $LegacySMB = Read-Host -Prompt "Will you be using legacy SMB permissions checking?  (Win2008R2/Win7, y/n)"
    if ($LegacySMB -eq 'y') {
        ($BaseConfig.root.components.avdurow.component | where {$_.name -eq 'Test-SharePermissions'}).enabled = 'FALSE'
        ($BaseConfig.root.components.avdurow.component | where {$_.name -eq 'Test-LegacySMBPermissions'}).enabled = 'TRUE'
    }

    Write-Output "`n---------------------`n"
    Write-Output "Enough data collection -- please review these values:`n"

    $BaseSettings = $BaseConfig.root.childnodes | where {$_.name -ne 'components'}
    foreach ($Setting in $BaseSettings) {
        Write-Output "$($Setting.name) : $($Setting.'#text')"
    }

    $Save = Read-Host "`nDo these values look correct? (y/n)"

    if ($Save -eq 'y') {
        $CurrentModPath = (Split-Path $PSScriptRoot -Parent)
        $BaseModPath = Split-Path $CurrentModPath -Parent
        $ConfigPath = "$BaseModPath\$($BaseConfig.root.ELHCversion)\ELHC.config"
        $BaseConfig.Save($ConfigPath)
        Write-Output "`nConfig file built and saved at $ConfigPath"
        
    }

    else {
        Write-Output "Config file was not saved... try again."
    }
}
